@@ -128,19 +128,23 @@ def main():
 
 
 
-    #Load Stylesheet for buttons
+    #Load Stylesheet
     try:
-        file = open(data.configFolder+"UIStyle2.css", 'r')
+        file = open(data.configFolder+"UIStyle.css_user.css", 'r')
         data.UIStyle=""
         for line in file: data.UIStyle=data.UIStyle+line+"\n"
         file.close()
         print "Loaded user defined style sheet"
     except:
-#        print "User defined style sheet not existing or not readable"
-#        file = open(data.app_path+"UIStyle.css", 'r')
-        data.UIStyle=""
-#        for line in file: data.UIStyle=data.UIStyle+line+"\n"
-#        file.close()
+        print "User defined style sheet not existing or not readable, load default one"
+        print "If you want to use a user defined style sheet, place it under", data.configFolder+"UIStyle_user.css"
+        try:
+            file = open(data.app_path+"UIStyle", 'r')
+            data.UIStyle=""
+            for line in file: data.UIStyle=data.UIStyle+line+"\n"
+            file.close()
+        except:
+            pass
 #        try:
 #            print "Create user defined style sheet in",  data.configFolder
 #            file= open(data.configFolder+"UIStyle.css", 'w')
@@ -461,10 +465,7 @@ class frmStartWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bView, QtCore.SIGNAL("clicked()"), self.ShowViewWindow)
         QtCore.QObject.connect(self.ui.bSetAlarm, QtCore.SIGNAL("clicked()"), self.SetAlarm)
 
-        #Add styles to buttons
-        self.ui.bCollecting.setStyleSheet(data.UIStyle)
-        self.ui.bSetAlarm.setStyleSheet(data.UIStyle)
-        self.ui.bView.setStyleSheet(data.UIStyle)
+        self.setStyleSheet(data.UIStyle) #Add styles
 
 
         QtCore.QObject.connect(self.ui.actionTest_recording, QtCore.SIGNAL("triggered()"), self.StartMeasurementQuick)
@@ -472,7 +473,6 @@ class frmStartWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
         QtCore.QObject.connect(self.ui.actionHelp, QtCore.SIGNAL("triggered()"), self.ShowHelpWindow)
 
-
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser2.png"))
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
@@ -598,6 +598,7 @@ class frmStartWindow(QMainWindow):
 
 
     def ShowHelpWindow(self): ##(Class StartWindow)
+        HelpWindow.load_data()
         HelpWindow.show()
 
 
@@ -650,8 +651,6 @@ class frmRecordWindow(QMainWindow):
 
         self.ui = Ui_RecordWindow()
         self.ui.setupUi(self)
-
-
         app.processEvents() #force ui update
 
 #        scroller = self.ui.ScrollArea.property("kineticScroller").toPyObject()
@@ -672,13 +671,7 @@ class frmRecordWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.actionHelp, QtCore.SIGNAL("triggered()"), self.ShowHelpWindow)
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
 
-        #Add styles to buttons
-        self.ui.bStop.setStyleSheet(data.UIStyle)
-        self.ui.bRaiseTrigger.setStyleSheet(data.UIStyle)
-        self.ui.bLowerTrigger.setStyleSheet(data.UIStyle)
-        self.ui.bZoomIn.setStyleSheet(data.UIStyle)
-        self.ui.bZoomOut.setStyleSheet(data.UIStyle)
-        self.ui.bEditNote.setStyleSheet(data.UIStyle)
+        self.setStyleSheet(data.UIStyle) #Add styles
 
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bZoomIn.setIcon(QIcon(data.app_path+"img/"+"zoom-in.png"))
@@ -911,22 +904,7 @@ class frmViewWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.actionShowRecordData, QtCore.SIGNAL("triggered()"), self.ShowRecordData)
         QtCore.QObject.connect(self.ui.actionExport, QtCore.SIGNAL("triggered()"), self.Export)
 
-
-        #Add styles to buttons
-        self.ui.bRaiseTrigger.setStyleSheet(data.UIStyle)
-        self.ui.bLowerTrigger.setStyleSheet(data.UIStyle)
-        self.ui.bZoomIn.setStyleSheet(data.UIStyle)
-        self.ui.bZoomOut.setStyleSheet(data.UIStyle)
-        self.ui.bNext.setStyleSheet(data.UIStyle)
-        self.ui.bLast.setStyleSheet(data.UIStyle)
-        self.ui.bDelete.setStyleSheet(data.UIStyle)
-        self.ui.bOpen.setStyleSheet(data.UIStyle)
-        self.ui.bOpenDate.setStyleSheet(data.UIStyle)
-        self.ui.bEditNote.setStyleSheet(data.UIStyle)
-        self.ui.bStatistics.setStyleSheet(data.UIStyle)
-
-
-
+        self.setStyleSheet(data.UIStyle) #Add styles
 
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bLast.setIcon(QIcon(data.app_path+"img/"+"arrow-left-double.png"))
@@ -1328,6 +1306,11 @@ class frmHelpWindow(QMainWindow):
         self.ui = Ui_HelpWindow()
         self.ui.setupUi(self)
 
+        self.setStyleSheet(data.UIStyle) #Add styles
+
+
+
+    def load_data(self):
 #        TODO: support multilingual info file
         file = open(data.app_path+"Info.htm", 'r')
         txt=""
@@ -1338,6 +1321,9 @@ class frmHelpWindow(QMainWindow):
         self.setWindowTitle("SleepAnalyser ("+_("Help")+")")
 
 
+
+
+
     def closeEvent(self, event): ##(Class HelpWindow)
         self.close()
         StartWindow.show()
@@ -1367,16 +1353,7 @@ class frmConfigWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bOK, QtCore.SIGNAL("clicked()"), self.OK)
 #        QtCore.QObject.connect(self.ui.bCancel, QtCore.SIGNAL("clicked()"), self.Cancel)
 
-
-        #Add styles to buttons
-        self.ui.bEditUserName.setStyleSheet(data.UIStyle)
-        self.ui.SlrDelayStart.setStyleSheet(data.UIStyle)
-        self.ui.SlrYscale_Movement.setStyleSheet(data.UIStyle)
-
-        #Add styles to tick boxes
-        self.ui.cOfflineMode.setStyleSheet(data.UIStyle)
-        self.ui.cStopAfterAlarm.setStyleSheet(data.UIStyle)
-        self.ui.cSilentProfile.setStyleSheet(data.UIStyle)
+        self.setStyleSheet(data.UIStyle) #Add styles
 
         self.setWindowTitle("SleepAnalyser ("+_("Settings")+")")
         self.ui.cOfflineMode.setText(_("Change to Offline Mode while recording"))
@@ -1523,6 +1500,8 @@ class frmDateWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.cal, QtCore.SIGNAL('selectionChanged()'), self.DateChanged)
         QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.OpenRecord)
 
+        self.setStyleSheet(data.UIStyle) #Add styles
+
         self.ui.cal.showToday()
 
         self.setWindowTitle("SleepAnalyser ("+_("Select date)")+")")
@@ -1541,7 +1520,7 @@ class frmDateWindow(QMainWindow):
 
         amount=len(arr)-1
 
-#TODO: visualise dates with records
+#TODO: visualise dates with records (=> not easely possible)
 
         txt=string.replace(_("Found % Record(s) for this date."),"%", str(amount))
         self.ui.lblResult.setText(txt)
@@ -1585,6 +1564,8 @@ class frmAdditionalInfoWindow(QMainWindow):
         self.ui = Ui_AdditionalInfoWindow()
         self.ui.setupUi(self)
 
+        self.setStyleSheet(data.UIStyle) #Add styles
+
         self.setWindowTitle("SleepAnalyser ("+_("Record Info\'s")+")")
 
 
@@ -1697,9 +1678,7 @@ class frmAlarmTimeWindow(QMainWindow):
 
         QtCore.QObject.connect(self.ui.bSetAlarm, QtCore.SIGNAL("clicked()"), self.SetAlarm)
 
-        #Add styles to buttons
-        self.ui.bSetAlarm.setStyleSheet(data.UIStyle)
-
+        self.setStyleSheet(data.UIStyle) #Add styles
 
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
@@ -1812,10 +1791,7 @@ class frmAskForKeepWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bstop_removeRecord, QtCore.SIGNAL("clicked()"), self.RemoveRecord)
         QtCore.QObject.connect(self.ui.bcontinue, QtCore.SIGNAL("clicked()"), self.ContinueRecording)
 
-        #Add styles to buttons
-        self.ui.bstop_keepRecord.setStyleSheet(data.UIStyle)
-        self.ui.bstop_removeRecord.setStyleSheet(data.UIStyle)
-        self.ui.bcontinue.setStyleSheet(data.UIStyle)
+        self.setStyleSheet(data.UIStyle) #Add styles
 
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bstop_keepRecord.setIcon(QIcon(data.app_path+"img/"+"zoom.png"))
